<?php
/**
 * The template for displaying featured content
 *
 * @package Fotografie
 */

$enable_content = get_theme_mod( 'fotografie_featured_content_option', 'homepage' );

if ( ! fotografie_check_section( $enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

$type = get_theme_mod( 'fotografie_featured_content_type', 'category' );

if ( 'image' !== $type ) {
	$featured_posts = fotografie_get_featured_posts();

	if ( empty( $featured_posts ) ) {
		return;
	}
}

$title     = get_theme_mod( 'fotografie_featured_content_archive_title', esc_html__( 'Featured', 'fotografie-pro' ) );
$sub_title = get_theme_mod( 'fotografie_featured_content_sub_title' );
$layout    = get_theme_mod( 'fotografie_featured_content_layout', 'layout-three' );
?>

<div id="featured-content-section" class="section <?php echo esc_attr( $layout ); ?>">
	<?php if ( '' !== $title || $sub_title ) : ?>
		<div class="blog-section-headline section-heading-wrap">
			<?php if ( '' !== $title ) : ?>
				<div class="page-title-wrapper">
					<h2 class="page-title section-title"><?php echo wp_kses_post( $title ); ?></h2>
				</div><!-- .page-title-wrapper -->
			<?php endif; ?>

			<?php if ( $sub_title ) : ?>
				<div class="taxonomy-description-wrapper">
					<p class="taxonomy-description section-subtitle"><?php echo wp_kses_post( $sub_title ); ?></p>
				</div><!-- .taxonomy-description-wrapper -->
			<?php endif; ?>
		</div><!-- .section-heading-wrap -->
	<?php endif; ?>

	<div class="featured-content-wrapper <?php echo esc_attr( $layout ); ?>">

		<?php
		if ( 'image' === $type ) {
			get_template_part( 'components/features/featured-content/content', 'image' );
		} else {
			foreach ( $featured_posts as $post ) {
				setup_postdata( $post );

				// Include the featured content template.
				get_template_part( 'components/features/featured-content/content', 'featured' );
			}

			wp_reset_postdata();
		}
		?>
	</div><!-- .featured-content-wrapper -->
</div><!-- #featured-content-section -->
