<?php
/**
 * Fotografie Pro Featured Slider Options
 * @package Fotografie Pro
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function fotografie_slider_options( $wp_customize ) {
	$wp_customize->add_section( 'fotografie_featured_slider', array(
		'panel' => 'fotografie_theme_options',
		'title' => esc_html__( 'Featured Slider', 'fotografie-pro' ),
	) );

	$wp_customize->add_setting( 'fotografie_slider_option', array(
		'default'			=> 'disabled',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_slider_option', array(
		'choices'   => fotografie_section_visibility_options(),
		'label'    	=> esc_html__( 'Enable on', 'fotografie-pro' ),
		'section'  	=> 'fotografie_featured_slider',
		'type'    	=> 'select',
	) );

	$wp_customize->add_setting( 'fotografie_move_slider', array(
		'sanitize_callback'	=> 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'fotografie_move_slider', array(
		'active_callback' => 'fotografie_is_slider_active',
		'label'           => esc_html__( 'Move Slider Above Header', 'fotografie-pro' ),
		'section'         => 'fotografie_featured_slider',
		'type'            => 'checkbox',
	) );

	$wp_customize->add_setting( 'fotografie_slider_transition_effect', array(
		'default'			=> 'fade',
		'sanitize_callback'	=> 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_slider_transition_effect' , array(
		'active_callback' => 'fotografie_is_slider_active',
		'choices'         => fotografie_slider_transition_effects(),
		'label'           => esc_html__( 'Transition Effect', 'fotografie-pro' ),
		'section'         => 'fotografie_featured_slider',
		'type'            => 'select',
		)
	);

	$wp_customize->add_setting( 'fotografie_slider_transition_delay', array(
		'default'			=> '4',
		'sanitize_callback'	=> 'absint',
	) );

	$wp_customize->add_control( 'fotografie_slider_transition_delay' , array(
		'active_callback'	=> 'fotografie_is_slider_active',
		'description'	=> esc_html__( 'seconds(s)', 'fotografie-pro' ),
		'input_attrs' => array(
			'style' => 'width: 40px;',
		),
		'label'    		=> esc_html__( 'Transition Delay', 'fotografie-pro' ),
		'section'  		=> 'fotografie_featured_slider',
		)
	);

	$wp_customize->add_setting( 'fotografie_slider_transition_length', array(
		'default'			=> '1',
		'sanitize_callback'	=> 'absint',
	) );

	$wp_customize->add_control( 'fotografie_slider_transition_length' , array(
		'active_callback' => 'fotografie_is_slider_active',
		'description'     => esc_html__( 'seconds(s)', 'fotografie-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 100px;',
		),
		'label'    		=> esc_html__( 'Transition Length', 'fotografie-pro' ),
		'section'  		=> 'fotografie_featured_slider',
		)
	);

	$wp_customize->add_setting( 'fotografie_slider_image_loader', array(
		'default'			=> 'false',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_slider_image_loader', array(
		'active_callback' => 'fotografie_is_slider_active',
		'choices'         => fotografie_slider_image_loader(),
		'label'           => esc_html__( 'Image Loader', 'fotografie-pro' ),
		'section'         => 'fotografie_featured_slider',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'fotografie_slider_type', array(
		'default'			=> 'category',
		'sanitize_callback'	=> 'fotografie_sanitize_select',
	) );

	$type = fotografie_section_type_options();

	unset( $type['demo'] );

	$wp_customize->add_control( 'fotografie_slider_type', array(
		'active_callback' => 'fotografie_is_slider_active',
		'choices'         => $type,
		'label'           => esc_html__( 'Select Slider Type', 'fotografie-pro' ),
		'section'         => 'fotografie_featured_slider',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'fotografie_slider_number', array(
		'default'			=> '4',
		'sanitize_callback'	=> 'fotografie_sanitize_number_range',
	) );

	$wp_customize->add_control( 'fotografie_slider_number' , array(
			'active_callback' => 'fotografie_is_slider_active',
			'description'     => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'fotografie-pro' ),
			'input_attrs'     => array(
				'style' => 'width: 45px;',
				'min'   => 0,
				'max'   => 20,
				'step'  => 1,
				),
			'label'    		=> esc_html__( 'No of Slides', 'fotografie-pro' ),
			'section'  		=> 'fotografie_featured_slider',
			'type'	   		=> 'number',
			'transport'		=> 'postMessage',
		)
	);

	$wp_customize->add_setting( 'fotografie_slider_content_show', array(
		'default'			=> 'excerpt',
		'sanitize_callback'	=> 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_slider_content_show', array(
		'active_callback' => 'fotografie_is_slider_active',
		'choices'         => fotografie_content_show(),
		'label'           => esc_html__( 'Display Content', 'fotografie-pro' ),
		'section'         => 'fotografie_featured_slider',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'fotografie_exclude_slider_post', array(
		'sanitize_callback'	=> 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'fotografie_exclude_slider_post', array(
		'active_callback'	=> 'fotografie_is_post_slider_active',
		'label'		=> esc_html__( 'Check to exclude Slider post from Homepage posts', 'fotografie-pro' ),
		'section'   => 'fotografie_featured_slider',
		'type'		=> 'checkbox',
	) );

	$wp_customize->add_setting( 'fotografie_slider_select_category', array(
		'sanitize_callback'	=> 'fotografie_sanitize_category_list',
	) );

	$wp_customize->add_control( new Fotografie_Multi_Category_Control( $wp_customize, 'fotografie_slider_select_category', array(
		'active_callback' => 'fotografie_is_category_slider_active',
		'label'           => esc_html__( 'Select Categories', 'fotografie-pro' ),
		'name'            => 'fotografie_slider_select_category',
		'section'         => 'fotografie_featured_slider',
		'type'            => 'dropdown-categories',
	) ) );

	$slider_number = get_theme_mod( 'fotografie_slider_number', 4 );

	for ( $i = 1; $i <= $slider_number ; $i++ ) {
		// Post Sliders
		$wp_customize->add_setting( 'fotografie_slider_post_' . $i, array(
			'sanitize_callback'	=> 'fotografie_sanitize_post',
		) );

		$wp_customize->add_control( 'fotografie_slider_post_' . $i, array(
			'active_callback'	=> 'fotografie_is_post_slider_active',
			'input_attrs' => array(
				'style' => 'width: 80px;',
			),
			'label'    	=> esc_html__( 'Post', 'fotografie-pro' ) . ' # ' . $i,
			'section'  	=> 'fotografie_featured_slider',
			'type'	   	=> 'text',
			)
		);

		// Page Sliders
		$wp_customize->add_setting( 'fotografie_slider_page_' . $i, array(
			'sanitize_callback'	=> 'fotografie_sanitize_post',
		) );

		$wp_customize->add_control( 'fotografie_slider_page_' . $i, array(
			'active_callback'	=> 'fotografie_is_page_slider_active',
			'label'    	=> esc_html__( 'Page', 'fotografie-pro' ) . ' # ' . $i,
			'section'  	=> 'fotografie_featured_slider',
			'type'	   	=> 'dropdown-pages',
		) );

		// Image Sliders
		$wp_customize->add_setting( 'fotografie_slider_note_' . $i, array(
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Fotografie_Note_Control( $wp_customize, 'featured_slider_note_' . $i, array(
			'active_callback' => 'fotografie_is_image_slider_active',
			'label'           => esc_html__( 'Slide #', 'fotografie-pro' ) . $i,
			'section'         => 'fotografie_featured_slider',
			'type'            => 'description',
		) ) );

		$wp_customize->add_setting( 'fotografie_slider_image_' . $i, array(
			'sanitize_callback'	=> 'fotografie_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fotografie_slider_image_' . $i, array(
			'active_callback' => 'fotografie_is_image_slider_active',
			'label'           => esc_html__( 'Image', 'fotografie-pro' ),
			'section'         => 'fotografie_featured_slider',
		) ) );

		$wp_customize->add_setting( 'fotografie_featured_link_' . $i, array(
			'sanitize_callback'	=> 'esc_url_raw',
		) );

		$wp_customize->add_control(  'fotografie_featured_link_' . $i, array(
			'active_callback' => 'fotografie_is_image_slider_active',
			'label'           => esc_html__( 'Link', 'fotografie-pro' ),
			'section'         => 'fotografie_featured_slider',
		) );

		$wp_customize->add_setting( 'fotografie_featured_target_' . $i, array(
			'sanitize_callback'	=> 'fotografie_sanitize_checkbox',
		) );

		$wp_customize->add_control(  'fotografie_featured_target_' . $i, array(
			'active_callback'	=> 'fotografie_is_image_slider_active',
			'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'fotografie-pro' ),
			'section'   => 'fotografie_featured_slider',
			'type'		=> 'checkbox',
		) );

		$wp_customize->add_setting( 'fotografie_featured_title_' . $i, array(
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control(  'fotografie_featured_title_' . $i, array(
			'active_callback'	=> 'fotografie_is_image_slider_active',
			'label'		=> esc_html__( 'Title', 'fotografie-pro' ),
			'section'   => 'fotografie_featured_slider',
			'type'		=> 'text',
		) );

		$wp_customize->add_setting( 'fotografie_featured_content_' . $i, array(
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'fotografie_featured_content_' . $i, array(
			'active_callback'	=> 'fotografie_is_image_slider_active',
			'label'		=> esc_html__( 'Content', 'fotografie-pro' ),
			'section'   => 'fotografie_featured_slider',
			'type'		=> 'textarea',
		) );
	} // End for().
}
add_action( 'customize_register', 'fotografie_slider_options' );


/**
 * Returns an array of feature slider transition effects
 *
 * @since Fotografie Pro 1.1
 */
function fotografie_slider_transition_effects() {
	$options = array(
		'fade'       => esc_html__( 'Fade', 'fotografie-pro' ),
		'fadeout'    => esc_html__( 'Fade Out', 'fotografie-pro' ),
		'none'       => esc_html__( 'None', 'fotografie-pro' ),
		'scrollHorz' => esc_html__( 'Scroll Horizontal', 'fotografie-pro' ),
		'scrollVert' => esc_html__( 'Scroll Vertical', 'fotografie-pro' ),
		'flipHorz'   => esc_html__( 'Flip Horizontal', 'fotografie-pro' ),
		'flipVert'   => esc_html__( 'Flip Vertical', 'fotografie-pro' ),
		'tileSlide'  => esc_html__( 'Tile Slide', 'fotografie-pro' ),
		'tileBlind'  => esc_html__( 'Tile Blind', 'fotografie-pro' ),
		'shuffle'    => esc_html__( 'Shuffle', 'fotografie-pro' ),
	);

	return apply_filters( 'fotografie_slider_transition_effects', $options );
}


/**
 * Returns an array of featured slider image loader options
 *
 * @since Fotografie Pro 1.1
 */
function fotografie_slider_image_loader() {
	$options = array(
		'true'  => esc_html__( 'True', 'fotografie-pro' ),
		'wait'  => esc_html__( 'Wait', 'fotografie-pro' ),
		'false' => esc_html__( 'False', 'fotografie-pro' ),
	);

	return apply_filters( 'fotografie_slider_image_loader', $options );
}



/**
 * Returns an array of featured content show registered for Lucida.
 *
 * @since Fotografie Pro 1.1
 */
function fotografie_content_show() {
	$options = array(
		'excerpt'      => esc_html__( 'Show Excerpt', 'fotografie-pro' ),
		'hide-content' => esc_html__( 'Hide Content', 'fotografie-pro' ),
	);
	return apply_filters( 'fotografie_content_show', $options );
}
