<?php
/**
 * Adding support for WooCommerce Plugin
 */

if ( ! class_exists( 'WooCommerce' ) ) {
	// Bail if WooCommerce is not installed
	return;
}


if ( ! function_exists( 'fotografie_woocommerce_setup' ) ) :
	/**
	 * Sets up support for various WooCommerce features.
	 */
	function fotografie_woocommerce_setup() {
		add_theme_support( 'woocommerce' );

		if ( ! get_theme_mod( 'fotografie_product_gallery_zoom' ) ) {
			add_theme_support( 'wc-product-gallery-zoom' );
		}

		if ( ! get_theme_mod( 'fotografie_product_gallery_lightbox' ) ) {
			add_theme_support( 'wc-product-gallery-lightbox' );
		}

		if ( ! get_theme_mod( 'fotografie_product_gallery_slider' ) ) {
			add_theme_support( 'wc-product-gallery-slider' );
		}
	}
endif; //fotografie_woocommerce_setup
add_action( 'after_setup_theme', 'fotografie_woocommerce_setup' );


/**
 * Add WooCommerce Options to customizer
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function fotografie_woocommerce_options( $wp_customize ) {
	$wp_customize->add_setting( 'fotografie_woocommerce_layout', array(
		'default'           => 'no-sidebar-full-width',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_woocommerce_layout', array(
		'description' => esc_html__( 'Layout for WooCommerce Pages', 'fotografie-pro' ),
		'label'       => esc_html__( 'WooCommerce Layout', 'fotografie-pro' ),
		'section'     => 'fotografie_layout_options',
		'type'        => 'radio',
		'choices'     => array(
			'left-sidebar'                  => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'fotografie-pro' ),
			'no-sidebar'                    => esc_html__( 'No Sidebar', 'fotografie-pro' ),
			'no-sidebar-full-width'         => esc_html__( 'No Sidebar: Full Width', 'fotografie-pro' ),
			'no-sidebar-full-content-width' => esc_html__( 'No Sidebar: Full Content Width', 'fotografie-pro' ),
			'right-sidebar'                 => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'fotografie-pro' ),
		),
	) );

	// WooCommerce Options.
	$wp_customize->add_section( 'fotografie_woocommerce_options', array(
		'title'       => esc_html__( 'WooCommerce Options', 'fotografie-pro' ),
		'panel'       => 'fotografie_theme_options',
		'description' => esc_html__( 'Since these options are added via theme support, you will need to save and refresh the customizer to view the full effect.', 'fotografie-pro' ),
	) );

	$wp_customize->add_setting( 'fotografie_product_gallery_zoom', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'fotografie_product_gallery_zoom', array(
		'label'   => esc_html__( 'Check to disable Product Gallery Zoom', 'fotografie-pro' ),
		'section' => 'fotografie_woocommerce_options',
		'type'    => 'checkbox',
	) );

	$wp_customize->add_setting( 'fotografie_product_gallery_lightbox', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'fotografie_product_gallery_lightbox', array(
		'label'   => esc_html__( 'Check to disable Product Gallery Lightbox', 'fotografie-pro' ),
		'section' => 'fotografie_woocommerce_options',
		'type'    => 'checkbox',
	) );

	$wp_customize->add_setting( 'fotografie_product_gallery_slider', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'fotografie_product_gallery_slider', array(
		'label'   => esc_html__( 'Check to disable Product Gallery Slider', 'fotografie-pro' ),
		'section' => 'fotografie_woocommerce_options',
		'type'    => 'checkbox',
	) );
}
add_action( 'customize_register', 'fotografie_woocommerce_options' );


/**
 * Uses remove_action to remove the WooCommerce Wrapper and add_action to add Main Wrapper.
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );


if ( ! function_exists( 'fotografie_woocommerce_start' ) ) :
	function fotografie_woocommerce_start() {
		echo '<div id="primary" class="content-area"><main id="main" class="site-main" role="main">';
	}
endif; //fotografie_woocommerce_start
add_action( 'woocommerce_before_main_content', 'fotografie_woocommerce_start', 15 );


if ( ! function_exists( 'fotografie_woocommerce_end' ) ) :
	function fotografie_woocommerce_end() {
		echo '</main><!-- #main --></div><!-- #primary -->';
	}
endif; //fotografie_woocommerce_end
add_action( 'woocommerce_after_main_content', 'fotografie_woocommerce_end', 15 );

if ( ! function_exists( 'fotografie_woocommerce_wrapper_start' ) ) :
	function fotografie_woocommerce_wrapper_start() {
		echo '<div class="wrapper singular-section">';
	}
endif; //fotografie_woocommerce_start
add_action( 'woocommerce_before_main_content', 'fotografie_woocommerce_wrapper_start', 10 );

if ( ! function_exists( 'fotografie_woocommerce_wrapper_end' ) ) :
	function fotografie_woocommerce_wrapper_end() {
		echo '</div><!-- .wrapper -->';
	}
endif; //fotografie_woocommerce_end
add_action( 'woocommerce_sidebar', 'fotografie_woocommerce_wrapper_end', 20 );


function fotografie_woocommerce_shorting_start() {
	echo '<div class="woocommerce-shorting-wrapper">';
}
add_action( 'woocommerce_before_shop_loop', 'fotografie_woocommerce_shorting_start', 10 );


function fotografie_woocommerce_shorting_end() {
	echo '</div><!-- .woocommerce-shorting-wrapper -->';
}
add_action( 'woocommerce_before_shop_loop', 'fotografie_woocommerce_shorting_end', 40 );


function fotografie_woocommerce_product_container_start() {
	echo '<div class="product-container">';
}
add_action( 'woocommerce_before_shop_loop_item_title', 'fotografie_woocommerce_product_container_start', 20 );


function fotografie_woocommerce_product_container_end() {
	echo '</div><!-- .product-container -->';
}
add_action( 'woocommerce_after_shop_loop_item', 'fotografie_woocommerce_product_container_end', 20 );

/**
 * Remove breadcrumb from default position
 * Check template-parts/header/breadcrumb.php
 */
function fotografie_remove_wc_breadcrumbs() {
	remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
}
add_action( 'init', 'fotografie_remove_wc_breadcrumbs' );


/**
 * WooCommerce breadcrumb formatting with theme breadcrumb style
 */
add_filter( 'woocommerce_breadcrumb_defaults', 'fotografie_woocommerce_breadcrumbs' );
function fotografie_woocommerce_breadcrumbs() {
	return array(
			'delimiter'   => ' &#47; ',
			'wrap_before' => '<div class="wrapper"><nav class="woocommerce-breadcrumb entry-breadcrumbs" itemprop="breadcrumb">',
			'wrap_after'  => '</nav><!-- .entry-breadcrumbs --></div><!-- .wrapper -->',
			'before'      => '',
			'after'       => '',
			'home'        => _x( 'Home', 'breadcrumb', 'fotografie-pro' ),
		);
}
